#
# spec file for package ghc-vector-binary-instances
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name vector-binary-instances
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.5.2
Release:        6.1
Summary:        Instances of Data.Binary for vector
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/5.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
Instances for Binary for the types defined in the vector package, making it
easy to serialize vectors to and from disk. We use the generic interface to
vectors, so all vector types are supported. Specific instances are provided for
unboxed, boxed and storable vectors. . To serialize a vector: . >
*Data.Vector.Binary> let v = Data.Vector.fromList [1..10] >
*Data.Vector.Binary> v > fromList [1,2,3,4,5,6,7,8,9,10] :: Data.Vector.Vector
> *Data.Vector.Binary> encode v > Chunk
"NULNULNULNULNUL...NULNULNULtNULNULNULNULn" Empty . Which you can in turn
compress before writing to disk: . > compress . encode $ v > Chunk
"US139bNULNULN...229240,254:NULNULNUL" Empty . Try the cereal-vector package if
you are looking for Data.Serialize instances.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library
development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Jun 25 2023 Peter Simons <psimons@suse.com>
- Update vector-binary-instances to version 0.2.5.2 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jun 23 2023 Peter Simons <psimons@suse.com>
- Update vector-binary-instances to version 0.2.5.2 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Nov 27 2022 Peter Simons <psimons@suse.com>
- Update vector-binary-instances to version 0.2.5.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jul 22 2022 Peter Simons <psimons@suse.com>
- Update vector-binary-instances to version 0.2.5.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update vector-binary-instances to version 0.2.5.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Apr 12 2021 psimons@suse.com
- Update vector-binary-instances to version 0.2.5.2.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Sep  4 2020 psimons@suse.com
- Update vector-binary-instances to version 0.2.5.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Sep  4 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Mon Dec 23 2019 psimons@suse.com
- Add vector-binary-instances at version 0.2.5.1.
